#! /usr/bin/env python3
# -*- coding: utf-8 -*-
"""
.. module:: TODO
   :platform: Unix
   :synopsis: TODO.

.. moduleauthor:: Aljosha Friemann aljosha.friemann@gmail.com

"""

VERSION = "0.0.7"

import os

from . import system

def record(acodec, vcodec, threads, output, device_name = "VGA2USB", preset = "ultrafast"):
    if os.path.splitext(output)[1] == '':
        raise Exception("no format specified for output file: %s" % output)

    video_options = "-f v4l2 -i {device} -vcodec {vcodec}".format(
            device = system.get_video_device(device_name),
            vcodec = vcodec)

    audio_options = "-acodec {acodec}".format(
            acodec = acodec)

    general_options = "-preset {preset} -threads {threads}".format(
            preset = preset,
            threads = threads)

    system.ffmpeg(video_options, audio_options, general_options, output)

# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4 fenc=utf-8



#! /usr/bin/env python3
# -*- coding: utf-8 -*-
"""
.. module:: TODO
   :platform: Unix
   :synopsis: TODO.

.. moduleauthor:: Aljosha Friemann aljosha.friemann@gmail.com

"""

import os, subprocess, logging

from . import utils

logger = logging.getLogger(__name__)

def sh(cmd):
    logger.debug(cmd)
    return subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE).call() == 0

def read_file(path):
    content = None
    with open(path, 'r') as f:
        content = f.read()
    return content.strip()

def video_devices():
    device_root = '/sys/class/video4linux'
    try:
        for device in os.listdir(device_root):
            for root,dirs,files in os.walk(os.path.join(device_root, device)):
                yield (os.path.basename(root), read_file(os.path.join(root, 'name')))
                break
    except OSError as e:
        if e.errno == errno.ENOENT:
            raise Exception("no video4linux devices found in %s!" % device_root)
        else:
            raise

def get_video_device(name):
    device_names = []
    for device, device_name in video_devices():
        if name in device_name:
            return "/dev/%s" % device
        else:
            device_names.append(device_name)

    raise Exception("could not find device %s %s" % (name, device_names))

def ffmpeg(global_opts, video_opts, audio_opts, output_opts, output_path):
    logger.debug(global_opts)
    logger.debug(video_opts)
    logger.debug(audio_opts)
    logger.debug(general_opts)
    logger.debug(output_opts)

    return system.sh(format(
        "ffmpeg {global_options} {video_options} {audio_options} {output_options} {output}",
        global_options = global_opts,
        video_options = video_opts,
        audio_options = audio_opts,
        output_options = output_opts,
        output = output_path))

# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4 fenc=utf-8




import os, pip

# from pip.req import parse_requirements

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

def read_version():
    with open(os.path.join(os.path.dirname(__file__), 'recorder/__init__.py')) as f:
        for line in f:
            if 'VERSION' in line:
                version = line.split('=')[1].replace("\"", "").strip()
                return version

install_reqs = pip.req.parse_requirements('requirements.txt', session=pip.download.PipSession())

requirements = [str(ir.req) for ir in install_reqs if ir is not None]

setup(name             = "ece-recorder",
      author           = "Aljosha Friemann",
      author_email     = "aljosha.friemann@gmail.com",
      license          = "",
      version          = read_version(),
      description      = "EclipseConEurope recording script",
      url              = "www.bitbucket.org/afriemann/ece-recorder.git",
      keywords         = [],
      # download_url     = "",
      install_requires = requirements,
      long_description = read('README.rst'),
      classifiers      = [],
      packages         = ["recorder"],
      scripts          = ["scripts/recorder"]
)



#! /usr/bin/env python3
# -*- coding: utf-8 -*-
"""
.. module:: TODO
   :platform: Unix
   :synopsis: TODO.

.. moduleauthor:: Aljosha Friemann aljosha.friemann@gmail.com

"""

from string import Formatter

class EmptyNoneType(object):

    def __nonzero__(self):
        return False

    def __str__(self):
        return ''

    def __getattr__(self, name):
        return EmptyNone

    def __getitem__(self, idx):
        return EmptyNone

EmptyNone = EmptyNoneType()

class EmptyNoneFormatter(Formatter):

    def get_value(self, field_name, args, kwds):
        v = Formatter.get_value(self, field_name, args, kwds)
        if v is None:
            return EmptyNone
        return v

def format(string, *args, **kwargs):
    return EmptyNoneFormatter().format(string, *args, **kwargs)

# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4 fenc=utf-8
